@@ -1,6 +1,6 @@
-;;; simpleicons.el --- AUCTeX style for `simpleicons.sty' (v13.18.0)  -*- lexical-binding: t; -*-
+;;; simpleicons.el --- AUCTeX style for `simpleicons.sty' (v14.7.0)  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2023--2024 Free Software Foundation, Inc.
+;; Copyright (C) 2023--2025 Free Software Foundation, Inc.
 
 ;; Author: Arash Esbati <arash@gnu.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -24,8 +24,8 @@
 
 ;;; Commentary:
 
-;; This file adds support for `simpleicons.sty' (v13.18.0) from
-;; 2024/11/29.  `simpleicons.sty' is part of TeXLive.
+;; This file adds support for `simpleicons.sty' (v14.7.0) from
+;; 2025-02-21.  `simpleicons.sty' is part of TeXLive.
 
 ;;; Code:
 
@@ -39,6 +39,7 @@
 
 (defvar LaTeX-simpleicons-icons
   '("1001tracklists"
+    "1and1"
     "1dot1dot1dot1"
     "1panel"
     "1password"
@@ -63,6 +64,7 @@
     "academia"
     "accenture"
     "accusoft"
+    "accuweather"
     "acer"
     "acm"
     "actigraph"
@@ -74,23 +76,10 @@
     "adafruit"
     "adblock"
     "adblockplus"
+    "addydotio"
     "adguard"
     "adidas"
     "adminer"
-    "adobe"
-    "adobeacrobatreader"
-    "adobeaftereffects"
-    "adobeaudition"
-    "adobecreativecloud"
-    "adobedreamweaver"
-    "adobefonts"
-    "adobeillustrator"
-    "adobeindesign"
-    "adobelightroom"
-    "adobelightroomclassic"
-    "adobephotoshop"
-    "adobepremierepro"
-    "adobexd"
     "adonisjs"
     "adp"
     "adroll"
@@ -102,6 +91,7 @@
     "aeromexico"
     "aerospike"
     "aew"
+    "afdian"
     "affine"
     "affinity"
     "affinitydesigner"
@@ -109,6 +99,7 @@
     "affinitypublisher"
     "aframe"
     "afterpay"
+    "aftership"
     "agora"
     "aib"
     "aidungeon"
@@ -126,11 +117,13 @@
     "airindia"
     "airplayaudio"
     "airplayvideo"
+    "airserbia"
     "airtable"
     "airtel"
     "airtransat"
     "ajv"
     "akamai"
+    "akasaair"
     "akaunting"
     "akiflow"
     "alacritty"
@@ -213,6 +206,7 @@
     "antdesign"
     "antena3"
     "anthropic"
+    "antv"
     "anycubic"
     "anydesk"
     "anytype"
@@ -255,6 +249,7 @@
     "apmterminals"
     "apollographql"
     "apostrophe"
+    "appgallery"
     "appian"
     "appium"
     "apple"
@@ -297,7 +292,6 @@
     "asciinema"
     "asda"
     "aseprite"
-    "askfm"
     "assemblyscript"
     "asterisk"
     "astonmartin"
@@ -350,6 +344,7 @@
     "babelio"
     "babylondotjs"
     "backblaze"
+    "backbone"
     "backbonedotjs"
     "backendless"
     "backstage"
@@ -388,6 +383,7 @@
     "bentoml"
     "bereal"
     "betfair"
+    "betterdiscord"
     "betterstack"
     "bevy"
     "bigbasket"
@@ -494,9 +490,9 @@
     "caddy"
     "cadillac"
     "cafepress"
-    "caffeine"
     "cairographics"
     "cairometro"
+    "caixabank"
     "cakephp"
     "caldotcom"
     "calendly"
@@ -521,6 +517,7 @@
     "caterpillar"
     "cbc"
     "cbs"
+    "ccc"
     "ccleaner"
     "cdprojekt"
     "ce"
@@ -570,16 +567,15 @@
     "citroen"
     "civicrm"
     "civo"
-    "ckeditor4"
     "clarifai"
     "claris"
     "clarivate"
+    "claude"
     "clerk"
     "clevercloud"
     "clickhouse"
     "clickup"
     "clion"
-    "cliqz"
     "clockify"
     "clojure"
     "cloud66"
@@ -599,6 +595,7 @@
     "clyp"
     "cmake"
     "cncf"
+    "cnes"
     "cnet"
     "cnn"
     "cocacola"
@@ -641,14 +638,16 @@
     "coffeescript"
     "coggle"
     "cognizant"
-    "coil"
+    "cohost"
     "coinbase"
     "coinmarketcap"
+    "collaboraonline"
     "comicfury"
     "comma"
     "commerzbank"
     "commitlint"
     "commodore"
+    "commonlisp"
     "commonworkflowlanguage"
     "compilerexplorer"
     "composer"
@@ -667,6 +666,7 @@
     "contao"
     "contentful"
     "contentstack"
+    "continente"
     "contributorcovenant"
     "conventionalcommits"
     "convertio"
@@ -699,6 +699,7 @@
     "creativetechnology"
     "credly"
     "crehana"
+    "crewai"
     "crewunited"
     "criticalrole"
     "crowdin"
@@ -706,9 +707,11 @@
     "crunchbase"
     "crunchyroll"
     "cryengine"
+    "cryptomator"
     "cryptpad"
     "crystal"
     "csdn"
+    "css"
     "css3"
     "cssdesignawards"
     "cssmodules"
@@ -724,7 +727,7 @@
     "cypress"
     "cytoscapedotjs"
     "d"
-    "d3dotjs"
+    "d3"
     "dacia"
     "daf"
     "dailydotdev"
@@ -767,7 +770,6 @@
     "deepin"
     "deepl"
     "deepnote"
-    "delicious"
     "deliveroo"
     "dell"
     "delonghi"
@@ -783,7 +785,9 @@
     "deutschebahn"
     "deutschebank"
     "deutschepost"
+    "deutschetelekom"
     "deutschewelle"
+    "devbox"
     "devdotto"
     "devexpress"
     "deviantart"
@@ -859,6 +863,7 @@
     "e"
     "e3"
     "ea"
+    "eac"
     "eagle"
     "easyeda"
     "easyjet"
@@ -899,8 +904,6 @@
     "eleventy"
     "elgato"
     "elixir"
-    "eljueves"
-    "ello"
     "elm"
     "elsevier"
     "embarcadero"
@@ -938,6 +941,7 @@
     "ethiopianairlines"
     "etihadairways"
     "etsy"
+    "europeanunion"
     "eventbrite"
     "eventstore"
     "evernote"
@@ -950,6 +954,7 @@
     "expertsexchange"
     "expo"
     "express"
+    "expressdotcom"
     "expressvpn"
     "eyeem"
     "f1"
@@ -979,7 +984,6 @@
     "favro"
     "fcc"
     "fdroid"
-    "feathub"
     "fedex"
     "fedora"
     "feedly"
@@ -995,7 +999,9 @@
     "figma"
     "figshare"
     "fila"
+    "filament"
     "filedotio"
+    "filen"
     "files"
     "filezilla"
     "fineco"
@@ -1029,7 +1035,6 @@
     "fluke"
     "flutter"
     "flux"
-    "fluxus"
     "flydotio"
     "flyway"
     "fmod"
@@ -1052,7 +1057,6 @@
     "fossilscm"
     "foundryvirtualtabletop"
     "foursquare"
-    "foursquarecityguide"
     "fox"
     "foxtel"
     "fozzy"
@@ -1069,6 +1073,7 @@
     "freelancer"
     "freelancermap"
     "freenas"
+    "freenet"
     "freepik"
     "fresh"
     "frontendmentor"
@@ -1080,27 +1085,26 @@
     "fugacloud"
     "fujifilm"
     "fujitsu"
-    "funimation"
     "furaffinity"
     "furrynetwork"
     "fusionauth"
     "futurelearn"
+    "fyle"
     "g2"
     "g2a"
     "g2g"
     "galaxus"
-    "gameandwatch"
     "gamebanana"
     "gamedeveloper"
     "gamejolt"
     "gameloft"
     "gamemaker"
+    "gamescience"
     "garmin"
     "gatling"
     "gatsby"
     "gcore"
     "gdal"
-    "geant"
     "geeksforgeeks"
     "generalelectric"
     "generalmotors"
@@ -1135,12 +1139,14 @@
     "gitpod"
     "gitter"
     "glassdoor"
+    "gldotinet"
     "glide"
     "glitch"
     "globus"
     "glovo"
     "gltf"
     "gmail"
+    "gmx"
     "gnome"
     "gnometerminal"
     "gnu"
@@ -1218,6 +1224,7 @@
     "googletranslate"
     "gotomeeting"
     "grab"
+    "gradio"
     "gradle"
     "gradleplaypublisher"
     "grafana"
@@ -1235,6 +1242,7 @@
     "greensock"
     "griddotai"
     "gridsome"
+    "grocy"
     "groupme"
     "groupon"
     "grubhub"
@@ -1321,6 +1329,8 @@
     "homify"
     "honda"
     "honey"
+    "honeybadger"
+    "honeygain"
     "hono"
     "honor"
     "hootsuite"
@@ -1333,6 +1343,8 @@
     "houzz"
     "hp"
     "hsbc"
+    "htc"
+    "htcvive"
     "html5"
     "htmlacademy"
     "htmx"
@@ -1466,6 +1478,7 @@
     "jfrogpipelines"
     "jhipster"
     "jinja"
+    "jio"
     "jira"
     "jirasoftware"
     "jitpack"
@@ -1509,7 +1522,6 @@
     "kasasmart"
     "kashflow"
     "kaspersky"
-    "katacoda"
     "katana"
     "kaufland"
     "kde"
@@ -1519,6 +1531,7 @@
     "keenetic"
     "keepachangelog"
     "keepassxc"
+    "keeper"
     "keeweb"
     "kentico"
     "keras"
@@ -1542,6 +1555,7 @@
     "kit"
     "kitsu"
     "klarna"
+    "kleinanzeigen"
     "klm"
     "klook"
     "knative"
@@ -1571,6 +1585,7 @@
     "kubernetes"
     "kubuntu"
     "kucoin"
+    "kueski"
     "kuma"
     "kununu"
     "kuula"
@@ -1581,6 +1596,8 @@
     "lamborghini"
     "landrover"
     "langchain"
+    "langflow"
+    "langgraph"
     "languagetool"
     "lapce"
     "laragon"
@@ -1642,11 +1659,11 @@
     "lineageos"
     "linear"
     "lining"
-    "linkedin"
     "linkerd"
     "linkfire"
     "linksys"
     "linktree"
+    "linphone"
     "lintcode"
     "linux"
     "linuxcontainers"
@@ -1681,6 +1698,7 @@
     "lootcrate"
     "lospec"
     "lotpolishairlines"
+    "lottiefiles"
     "ltspice"
     "lua"
     "lubuntu"
@@ -1692,6 +1710,7 @@
     "lumen"
     "lunacy"
     "lutris"
+    "lvgl"
     "lydia"
     "lyft"
     "maas"
@@ -1699,7 +1718,6 @@
     "macpaw"
     "macys"
     "magasinsu"
-    "magento"
     "magic"
     "magisk"
     "mahindra"
@@ -1722,11 +1740,12 @@
     "manjaro"
     "mantine"
     "mapbox"
+    "mapillary"
     "maplibre"
+    "maptiler"
     "mariadb"
     "mariadbfoundation"
     "markdown"
-    "marketo"
     "marko"
     "marriott"
     "marvelapp"
@@ -1748,12 +1767,14 @@
     "maxplanckgesellschaft"
     "maytag"
     "mazda"
+    "maze"
     "mcafee"
     "mcdonalds"
     "mclaren"
     "mdbook"
     "mdnwebdocs"
     "mdx"
+    "mealie"
     "mediafire"
     "mediamarkt"
     "mediapipe"
@@ -1789,7 +1810,6 @@
     "microbit"
     "microdotblog"
     "microeditor"
-    "microgenetics"
     "micropython"
     "microstation"
     "microstrategy"
@@ -1823,6 +1843,7 @@
     "modin"
     "modrinth"
     "modx"
+    "mojeek"
     "moleculer"
     "momenteo"
     "monero"
@@ -1845,6 +1866,7 @@
     "morrisons"
     "moscowmetro"
     "motorola"
+    "movistar"
     "mozilla"
     "mpv"
     "mqtt"
@@ -1856,6 +1878,7 @@
     "mui"
     "mulesoft"
     "muller"
+    "mullvad"
     "multisim"
     "mumble"
     "muo"
@@ -1877,6 +1900,7 @@
     "namuwiki"
     "nano"
     "nanostores"
+    "napster"
     "nasa"
     "nationalgrid"
     "nationalrail"
@@ -1916,10 +1940,12 @@
     "nextdns"
     "nextdoor"
     "nextdotjs"
+    "nextflow"
     "nextra"
     "nextui"
     "nexusmods"
     "nfc"
+    "nfcore"
     "nginx"
     "nginxproxymanager"
     "ngrok"
@@ -1930,10 +1956,6 @@
     "nike"
     "nikon"
     "nim"
-    "nintendo"
-    "nintendo3ds"
-    "nintendogamecube"
-    "nintendoswitch"
     "nissan"
     "nixos"
     "nodedotjs"
@@ -1966,17 +1988,20 @@
     "nunjucks"
     "nushell"
     "nutanix"
-    "nuxtdotjs"
+    "nuxt"
     "nvidia"
     "nvm"
     "nx"
     "nxp"
     "nzxt"
     "o2"
+    "obb"
     "observable"
     "obsidian"
     "obsstudio"
+    "obtainium"
     "ocaml"
+    "oclc"
     "oclif"
     "octanerender"
     "octave"
@@ -1993,12 +2018,14 @@
     "okta"
     "okx"
     "ollama"
+    "omadacloud"
     "oneplus"
     "onlyfans"
     "onlyoffice"
     "onnx"
     "onstar"
     "opel"
+    "open3d"
     "openaccess"
     "openai"
     "openaigym"
@@ -2044,7 +2071,6 @@
     "opsgenie"
     "opslevel"
     "optimism"
-    "oracle"
     "orange"
     "orcid"
     "oreilly"
@@ -2087,6 +2113,7 @@
     "paperlessngx"
     "paperspace"
     "paperswithcode"
+    "paradoxinteractive"
     "paramountplus"
     "paritysubstrate"
     "parrotsecurity"
@@ -2132,6 +2159,7 @@
     "photon"
     "photopea"
     "php"
+    "phpbb"
     "phpmyadmin"
     "phpstorm"
     "piaggiogroup"
@@ -2141,6 +2169,7 @@
     "picnic"
     "picpay"
     "picrew"
+    "picsart"
     "picxy"
     "pihole"
     "pimcore"
@@ -2197,7 +2226,6 @@
     "poe"
     "poetry"
     "pointy"
-    "pokemon"
     "polars"
     "polestar"
     "polkadot"
@@ -2303,6 +2331,7 @@
     "qlik"
     "qmk"
     "qnap"
+    "qq"
     "qt"
     "qualcomm"
     "qualtrics"
@@ -2331,7 +2360,6 @@
     "racket"
     "radar"
     "radarr"
-    "radiopublic"
     "radixui"
     "radstudio"
     "railway"
@@ -2362,7 +2390,6 @@
     "readdotcv"
     "readme"
     "readthedocs"
-    "realm"
     "reason"
     "reasonstudios"
     "recoil"
@@ -2384,6 +2411,7 @@
     "redwoodjs"
     "reebok"
     "refine"
+    "refinedgithub"
     "relay"
     "relianceindustrieslimited"
     "remark"
@@ -2395,6 +2423,7 @@
     "renovate"
     "renpy"
     "renren"
+    "replicate"
     "replit"
     "republicofgamers"
     "rescript"
@@ -2411,7 +2440,6 @@
     "reverbnation"
     "revoltdotchat"
     "revolut"
-    "revue"
     "rewe"
     "rezgo"
     "rhinoceros"
@@ -2443,6 +2471,7 @@
     "roll20"
     "rollsroyce"
     "rollupdotjs"
+    "rook"
     "roon"
     "rootme"
     "roots"
@@ -2505,6 +2534,7 @@
     "saucelabs"
     "saudia"
     "scala"
+    "scalar"
     "scaleway"
     "scania"
     "schneiderelectric"
@@ -2577,12 +2607,14 @@
     "siemens"
     "sifive"
     "signal"
+    "silverairways"
     "similarweb"
     "simkl"
     "simpleanalytics"
     "simpleicons"
     "simplelogin"
     "simplenote"
+    "simplex"
     "sinaweibo"
     "singaporeairlines"
     "singlestore"
@@ -2597,7 +2629,6 @@
     "skoda"
     "sky"
     "skypack"
-    "skyrock"
     "slack"
     "slackware"
     "slashdot"
@@ -2607,7 +2638,6 @@
     "slint"
     "smart"
     "smartthings"
-    "smashdotgg"
     "smashingmagazine"
     "smrt"
     "smugmug"
@@ -2621,7 +2651,9 @@
     "snyk"
     "socialblade"
     "society6"
+    "socket"
     "socketdotio"
+    "softcatala"
     "softpedia"
     "sogou"
     "solana"
@@ -2665,7 +2697,6 @@
     "spigotmc"
     "spine"
     "spinnaker"
-    "spinrilla"
     "splunk"
     "spoj"
     "spond"
@@ -2674,8 +2705,8 @@
     "spreadshirt"
     "spreaker"
     "spring"
-    "springcreators"
     "springboot"
+    "springcreators"
     "springsecurity"
     "spyderide"
     "sqlalchemy"
@@ -2692,7 +2723,6 @@
     "stackexchange"
     "stackhawk"
     "stackoverflow"
-    "stackpath"
     "stackshare"
     "stadia"
     "staffbase"
@@ -2703,6 +2733,8 @@
     "stardock"
     "starlingbank"
     "starship"
+    "startdotgg"
+    "startpage"
     "startrek"
     "starz"
     "statamic"
@@ -2721,7 +2753,6 @@
     "stencil"
     "stencyl"
     "stimulus"
-    "stitcher"
     "stmicroelectronics"
     "stockx"
     "stopstalk"
@@ -2732,12 +2763,12 @@
     "streamlabs"
     "streamlit"
     "streamrunners"
+    "stremio"
     "stripe"
     "strongswan"
     "stryker"
     "stubhub"
     "studio3t"
-    "studyverse"
     "styledcomponents"
     "stylelint"
     "styleshare"
@@ -2756,6 +2787,7 @@
     "supercrease"
     "supermicro"
     "superuser"
+    "surfshark"
     "surrealdb"
     "surveymonkey"
     "suse"
@@ -2782,7 +2814,6 @@
     "synology"
     "system76"
     "tabelog"
-    "tableau"
     "tablecheck"
     "tacobell"
     "tado"
@@ -2818,11 +2849,11 @@
     "teespring"
     "tekton"
     "tele5"
+    "telefonica"
     "telegram"
     "telegraph"
     "telequebec"
     "temporal"
-    "tencentqq"
     "tensorflow"
     "teradata"
     "teratail"
@@ -2886,7 +2917,6 @@
     "tinyletter"
     "tistory"
     "tldraw"
-    "tmobile"
     "tmux"
     "todoist"
     "toggl"
@@ -2895,11 +2925,13 @@
     "toll"
     "toml"
     "tomorrowland"
+    "tomtom"
     "ton"
     "topcoder"
     "topdotgg"
     "toptal"
     "torbrowser"
+    "torizon"
     "torproject"
     "toshiba"
     "totvs"
@@ -2928,6 +2960,7 @@
     "trilium"
     "triller"
     "trillertv"
+    "trimble"
     "trino"
     "tripadvisor"
     "tripdotcom"
@@ -2952,7 +2985,7 @@
     "turbosquid"
     "turkishairlines"
     "turso"
-    "tutanota"
+    "tuta"
     "tv4play"
     "tvtime"
     "twilio"
@@ -2974,9 +3007,12 @@
     "ubuntumate"
     "udacity"
     "udemy"
+    "udotsdotnews"
     "ufc"
     "uikit"
     "uipath"
+    "ukca"
+    "ultralytics"
     "ulule"
     "umami"
     "umbraco"
@@ -3007,12 +3043,12 @@
     "ups"
     "upstash"
     "uptimekuma"
-    "uptobox"
     "upwork"
     "usps"
     "utorrent"
     "uv"
     "v"
+    "v0"
     "v2ex"
     "v8"
     "vaadin"
@@ -3033,7 +3069,9 @@
     "veepee"
     "vega"
     "vegas"
+    "velocity"
     "velog"
+    "vencord"
     "venmo"
     "vercel"
     "verdaccio"
@@ -3117,6 +3155,7 @@
     "webassembly"
     "webauthn"
     "webcomponentsdotorg"
+    "webdotde"
     "webdriverio"
     "webex"
     "webflow"
@@ -3144,8 +3183,7 @@
     "wgpu"
     "whatsapp"
     "wheniwork"
-    "wii"
-    "wiiu"
+    "wikibooks"
     "wikidata"
     "wikidotgg"
     "wikidotjs"
@@ -3153,8 +3191,10 @@
     "wikimediafoundation"
     "wikipedia"
     "wikiquote"
+    "wikiversity"
     "wikivoyage"
     "winamp"
+    "wine"
     "wipro"
     "wire"
     "wireguard"
@@ -3180,6 +3220,7 @@
     "writedotas"
     "wwe"
     "wwise"
+    "wxt"
     "wykop"
     "wyze"
     "x"
@@ -3200,6 +3241,7 @@
     "xsplit"
     "xstate"
     "xubuntu"
+    "xyflow"
     "yabai"
     "yale"
     "yamahacorporation"
@@ -3212,6 +3254,8 @@
     "yeti"
     "yii"
     "yoast"
+    "yolo"
+    "youhodler"
     "youtube"
     "youtubegaming"
     "youtubekids"
@@ -3244,7 +3288,6 @@
     "zensar"
     "zerodha"
     "zerotier"
-    "zerply"
     "zettlr"
     "zhihu"
     "zig"
