@@ -56,6 +56,8 @@
 (declare-function LaTeX-verbatim-macro-boundaries "latex")
 (declare-function LaTeX-verbatim-macros-with-braces "latex")
 (declare-function LaTeX-verbatim-macros-with-delims "latex")
+(declare-function bibtex-parse-entry "bibtex")
+(declare-function bibtex-text-in-field "bibtex")
 
 (defgroup TeX-fold nil
   "Fold TeX macros."
@@ -72,7 +74,7 @@ macros, `math' for math macros and `comment' for comments."
 
 (defcustom TeX-fold-macro-spec-list
   '(("[f]" ("footnote" "marginpar"))
-    ("[c]" ("cite"))
+    (TeX-fold-cite-display ("cite"))
     ("[l]" ("label"))
     ("[r]" ("ref" "pageref" "eqref" "footref"))
     ("[i]" ("index" "glossary"))
@@ -81,6 +83,10 @@ macros, `math' for math macros and `comment' for comments."
     ("(C)" ("copyright"))
     ("(R)" ("textregistered"))
     ("TM"  ("texttrademark"))
+    (TeX-fold-alert-display ("alert"))
+    (TeX-fold-textcolor-display ("textcolor"))
+    (TeX-fold-begin-display ("begin"))
+    (TeX-fold-end-display ("end"))
     (1 ("part" "chapter" "section" "subsection" "subsubsection"
         "paragraph" "subparagraph"
         "part*" "chapter*" "section*" "subsection*" "subsubsection*"
@@ -120,7 +126,8 @@ Customize or reset the mode."
   :type '(repeat (group (choice (string :tag "Display String")
                                 (integer :tag "Number of argument" :value 1)
                                 (function :tag "Function to execute"))
-                        (repeat :tag "Macros" (string)))))
+                        (repeat :tag "Macros" (string))))
+  :package-version '(auctex . "14.0.8"))
 
 (defvar-local TeX-fold-macro-spec-list-internal nil
   "Internal list of display strings and macros to fold.
@@ -356,53 +363,12 @@ and `TeX-fold-math-spec-list', and environments in `TeX-fold-env-spec-list'."
       (TeX-fold-clearout-region start end)
       (TeX-fold-region start end))))
 
-(defcustom TeX-fold-region-functions '(TeX-fold-verbs)
+(defcustom TeX-fold-region-functions '(TeX-fold-verbs TeX-fold-quotes)
   "List of additional functions to call when folding a region.
 Each function is called with two arguments, the start and end positions
 of the region to fold."
   :type '(repeat function)
-  :package-version '(auctex . "14.0.7"))
-
-(defun TeX-fold--verb-data (&rest _args)
-  "Return data describing verbatim macro at point.
-Returns list of the form (START END CONTENT).  This should be called
-only in LaTeX modes."
-  (when-let* ((boundaries (LaTeX-verbatim-macro-boundaries))
-              (bound-start (car boundaries))
-              (bound-end (cdr boundaries))
-              (end-delim-char (char-before bound-end))
-              (start-delim-char (if (= end-delim-char ?\})
-                                    ?\{
-                                  end-delim-char))
-              (start-delim (char-to-string start-delim-char))
-              (verb-arg-start
-               (1+ (progn
-                     (goto-char bound-end)
-                     (if (string= start-delim TeX-grop)
-                         (progn (backward-sexp) (point))
-                       (forward-char -1)
-                       (search-backward start-delim bound-start t)))))
-              (verb-arg-end (1- bound-end)))
-    (list bound-start
-          bound-end
-          (buffer-substring verb-arg-start verb-arg-end))))
-
-(defun TeX-fold-verbs (start end)
-  "In LaTeX modes, fold verbatim macros between START and END."
-  (when (derived-mode-p 'LaTeX-mode)
-    (save-excursion
-      (goto-char start)
-      (let ((re (concat (regexp-quote TeX-esc)
-                        (regexp-opt
-                         (append
-                          (LaTeX-verbatim-macros-with-braces)
-                          (LaTeX-verbatim-macros-with-delims))))))
-        (while (let ((case-fold-search nil))
-                 (re-search-forward re end t))
-          (when-let* ((data (TeX-fold--verb-data))
-                      (spec (lambda (&rest _args)
-                              (nth 2 (TeX-fold--verb-data)))))
-            (apply #'TeX-fold--make-misc-overlay (append data (list spec)))))))))
+  :package-version '(auctex . "14.0.8"))
 
 (defun TeX-fold-region (start end)
   "Fold all items in region from START to END."
@@ -611,17 +577,297 @@ Return non-nil if a comment was found and folded, nil otherwise."
           (TeX-fold-hide-item (TeX-fold-make-overlay beg (point) 'comment
                                                      TeX-fold-ellipsis)))))))
 
+;;; Display functions
+
+;; This section provides functions for use in `TeX-fold-macro-spec-list'.
+
+;;;; textcolor
+
+(defun TeX-fold-textcolor-display (color text &rest _args)
+  "Fold display for a \\textcolor{COLOR}{TEXT} macro."
+  (with-temp-buffer
+    (insert text)
+    (put-text-property (point-min) (point-max)
+                       'face `(:foreground ,color)
+                       (current-buffer))
+    (buffer-string)))
+
+;;;; alert
+
+(defcustom TeX-fold-alert-color "red"
+  "Color for alert text."
+  :type 'color
+  :package-version '(auctex . "14.0.8"))
+
+(defun TeX-fold-alert-display (text &rest _args)
+  "Fold display for a \\alert{TEXT} macro."
+  (with-temp-buffer
+    (insert text)
+    (put-text-property (point-min) (point-max)
+                       'face `(:foreground ,TeX-fold-alert-color)
+                       (current-buffer))
+    (buffer-string)))
+
+;;;; begin/end
+
+(defcustom TeX-fold-begin-end-spec-list
+  '((("↴" . "↲")
+     ("itemize" "enumerate" "description" "frame"))
+    ((TeX-fold-format-titled-block . "◼")
+     ("block"))
+    ((TeX-fold-format-titled-alertblock . "◼")
+     ("alertblock"))
+    ((TeX-fold-format-theorem-environment . "□")
+     ("proof"))
+    ((TeX-fold-format-theorem-environment . "◼")
+     ("abstract"
+      "acknowledgment"
+      "algorithm"
+      "assumptions"
+      "claim"
+      "commentary"
+      "fact"
+      "note"
+      "questions"
+      ("answer" "ans")
+      ("conclusion" "conc")
+      ("condition" "cond")
+      ("conjecture" "conj")
+      ("corollary" "cor")
+      ("criterion" "crit")
+      ("definition" "def" "defn")
+      ("example" "ex")
+      ("exercise" "exer")
+      ("lemma" "lem")
+      ("notation" "not")
+      ("problem" "prob")
+      ("proposition" "prop")
+      ("question" "ques")
+      ("remark" "rem" "rmk")
+      ("summary" "sum")
+      ("terminology" "term")
+      ("theorem" "thm"))))
+  "Replacement specifier list for \\begin{env} and \\end{env} macros.
+
+This option is relevant only if the replacement specifiers in
+`TeX-fold-macro-spec-list' for \"begin\" and \"end\" macros are the
+defaults, namely `TeX-fold-begin-display' and `TeX-fold-end-display'.
+
+Each item is a list consisting of two elements:
+
+The first element is a cons cell, with car and cdr the display
+specifications for \\begin{...} and \\end{...}  macros, respectively.
+Each specification is either
+
+  - a string, used as the fold display string, or
+
+  - a function, called with the (unabbreviated) environment name and a
+    list consisting of the remaining mandatory macro arguments, that
+    returns a string.
+
+The second element is a list of environment types, which are either
+
+- the environment name, e.g., \"remark\", or
+
+- a list with first element an environment name and remaining elements
+  any abbreviated environment names, e.g., (\"remark\" \"rem\" \"rmk\")."
+  :type '(repeat
+          (group
+           (cons (choice (string :tag "Display String for \\begin{...}")
+                         (function :tag "Function to execute for \\begin{...}"))
+                 (choice (string :tag "Display String for \\end{...}")
+                         (function :tag "Function to execute for \\end{...}")))
+           (repeat :tag "Environment Types"
+                   (choice (string :tag "Environment")
+                           (cons :tag "Environment and Abbreviations"
+                                 (string :tag "Environment")
+                                 (repeat :tag "Abbreviations"
+                                         (string :tag "Abbreviation")))))))
+  :package-version '(auctex . "14.0.8"))
+
+
+(defun TeX-fold-begin-display (env &rest args)
+  "Fold display for a \\begin{ENV}.
+Intended for use in `TeX-fold-begin-end-spec-list'.  ARGS is a list
+consisting of the remaining mandatory macro arguments."
+  (TeX-fold--helper-display env args #'car))
+
+(defun TeX-fold-end-display (env &rest args)
+  "Fold display for a \\end{ENV} macro.
+Intended for use in `TeX-fold-begin-end-spec-list'.  ARGS is a list
+consisting of the remaining mandatory macro arguments."
+  (TeX-fold--helper-display env args #'cdr))
+
+(defun TeX-fold--helper-display (env args spec-retriever)
+  "Generate fold display string for \\begin{ENV} or \\end{ENV} macro.
+ARGS are the remaining mandatory macro arguments.  Returns the string or
+function determined by `TeX-fold-begin-end-spec-list' if ENV is found
+there, otherwise `abort'.  SPEC-RETRIEVER, which should be either `car'
+or `cdr', retrieves the appropriate part of the display specification."
+  (catch 'result
+    (dolist (item TeX-fold-begin-end-spec-list)
+      (let* ((spec (funcall spec-retriever (car item)))
+             (types (cadr item)))
+        (dolist (type types)
+          (when-let* ((name (cond ((stringp type)
+                                   (when (string= env type)
+                                     env))
+                                  ((consp type)
+                                   (when (member env type)
+                                     (car type))))))
+            (throw 'result
+                   (if (functionp spec)
+                       (funcall spec name args)
+                     spec))))))
+    'abort))
+
+;;;;; block environments
+
+(defun TeX-fold-format-titled-block (_env args)
+  "Format fold display for beamer block environments.
+Intended for use in `TeX-fold-begin-end-spec-list'.  ENV is ignored.
+ARGS is a list whose car will be the block title.
+
+Example: \"\\begin{block}{Theorem 1}\" folds to \"Theorem 1\"."
+  (car args))
+
+(defun TeX-fold-format-titled-alertblock (_env args)
+  "Format fold display for beamer alertblock environments.
+Intended for use in `TeX-fold-begin-end-spec-list'.  The arguments
+ENV/ARGS and the behavior are as in `TeX-fold-format-titled-block', but
+the folded text is colored using `TeX-fold-alert-color'."
+  (let ((caption (car args)))
+    (add-face-text-property 0 (length caption)
+                            `(:foreground ,TeX-fold-alert-color) nil caption)
+    (format "%s" caption)))
+
+;;;;; theorem-like environments
+
+(defun TeX-fold-format-theorem-environment (env _args)
+  "Format fold display for theorem-like LaTeX environments.
+Intended for use in `TeX-fold-begin-end-spec-list'.  ENV is the
+environment name, ARGS are ignored.  Returns a string of the form
+\"Environment \" or \"Environment (Description) \""
+  (let* ((env (with-temp-buffer
+                (insert env)
+                (goto-char (point-min))
+                (capitalize-word 1)
+                (buffer-string)))
+         (description
+          (car (TeX-fold-macro-nth-arg 1 (point)
+                                       (TeX-fold-item-end (point) 'macro)
+                                       '(?\[ . ?\])))))
+    (concat
+     (format "%s " env)
+     (when description
+       (format "(%s) " description)))))
+
+;;;; citations
+
+(defun TeX-fold--last-name (name)
+  "Return string consisting of last name of NAME.
+NAME should be of the form \"Last, First\" or \"First Last\", possibly
+with some additional non-alphabetical characters such as braces."
+  (if-let* ((comma (string-match "," name)))
+      (setq name (substring name 0 comma))
+    (when-let* ((space (string-match " " name)))
+      (setq name (substring name space))))
+  (when-let* ((index (string-match "[[:alpha:]]" name)))
+    (setq name (substring name index)))
+  (when-let* ((index (string-match "[^[:alpha:]]" name)))
+    (setq name (substring name 0 index)))
+  name)
+
+(defun TeX-fold--bib-abbrev-entry-at-point ()
+  "Abbreviate the BibTeX entry at point.
+Return string of the form \"XYZ99\", formed using authors' last names and
+publication year, or nil if author/year not found."
+  (require 'bibtex)
+  (when-let* ((case-fold-search t)
+              (entry (bibtex-parse-entry))
+              (author (bibtex-text-in-field "author" entry))
+              (year (bibtex-text-in-field "year" entry))
+              (last-names
+               (mapcar #'TeX-fold--last-name (string-split author " and ")))
+              (last-names (seq-filter (lambda (name) (> (length name) 0))
+                                      last-names))
+              (initials
+               (if (and (eq (length last-names) 1)
+                        (> (length (car last-names)) 1))
+                   (substring (car last-names) 0 2)
+                 (mapconcat (lambda (name)
+                              (substring name 0 1))
+                            last-names)))
+              (year-XX (when year (substring year -2))))
+    (concat initials year-XX)))
+
+(defun TeX-fold--bib-entry (key files)
+  "Retrieve BibTeX entry for KEY from FILES.
+Return first BibTeX entry found as a string, or nil if none found."
+  (when (fboundp 'reftex-pop-to-bibtex-entry)
+    (condition-case nil
+        (reftex-pop-to-bibtex-entry key files nil nil nil t)
+      (error nil))))
+
+(defcustom TeX-fold-bib-files nil
+  "List of BibTeX files from which to extract citation keys.
+This is used as a fallback option for citation folding when RefTeX can't
+find the citation keys in the provided bib files, and may be useful when
+using \\thebibliography or when working in non-file buffers."
+  :type '(repeat file)
+  :package-version '(auctex . "14.0.8"))
+
+(defun TeX-fold--bib-abbrev (key)
+  "Get abbreviation for BibTeX entry associated with KEY.
+Search using RefTeX (if available) and `TeX-fold-bib-file'.  Return
+string of the form \"XYZ99\" or nil if the key is not found or does not
+contain the required information."
+  (when-let* ((entry (or (and (bound-and-true-p reftex-mode)
+                              (fboundp 'reftex-get-bibfile-list)
+                              (when-let* ((files
+                                           (condition-case nil
+                                               (reftex-get-bibfile-list)
+                                             (error nil))))
+                                (TeX-fold--bib-entry key files)))
+                         (TeX-fold--bib-entry
+                          key TeX-fold-bib-files))))
+    (with-temp-buffer
+      (insert entry)
+      (goto-char (point-min))
+      (TeX-fold--bib-abbrev-entry-at-point))))
+
+(defun TeX-fold-cite-display (keys &rest _args)
+  "Fold display for a \\cite{KEYS} macro.
+KEYS are the citation key(s), as a comma-delimited list.  Return string
+of the form \"[XYZ99]\" or \"[XYZ99, Optional Citation Text]\", formed
+using authors' last names and the the publication year."
+  (let* ((citation (car (TeX-fold-macro-nth-arg
+                         1 (point)
+                         (TeX-fold-item-end (point) 'macro)
+                         '(?\[ . ?\]))))
+         (key-list (split-string keys "[ \f\t\n\r\v,]+"))
+         (references (delq nil (mapcar #'TeX-fold--bib-abbrev key-list)))
+         (joined-references (string-join references ", ")))
+    (concat "["
+            (if (string-empty-p joined-references)
+                "c" joined-references)
+            (when citation
+              (format ", %s" citation))
+            "]")))
 
 ;;; Utilities
 
-(defun TeX-fold-make-overlay (ov-start ov-end type display-string-spec)
+(defun TeX-fold-make-overlay (ov-start ov-end type display-string-spec
+                                       &optional display-string)
   "Make a TeX-fold overlay extending from OV-START to OV-END.
-TYPE is a symbol which is used to describe the content to hide
-and may be `macro' for macros, `math' for math macro and `env' for
-environments.
+TYPE is a symbol which is used to describe the content to hide and may
+be `macro' for macros, `math' for math macro, `env' for environments, or
+`misc' for miscellaneous constructs like quotes and dashes.
 DISPLAY-STRING-SPEC is the original specification of the display
 string in the variables `TeX-fold-macro-spec-list' and alikes.
-See its doc string for detail."
+See its doc string for detail.
+If DISPLAY-STRING is provided, it will be used directly as the overlay's
+display property."
   ;; Calculate priority before the overlay is instantiated.  We don't
   ;; want `TeX-overlay-prioritize' to pick up a non-prioritized one.
   (let ((priority (TeX-overlay-prioritize ov-start ov-end))
@@ -629,27 +875,11 @@ See its doc string for detail."
     (overlay-put ov 'category 'TeX-fold)
     (overlay-put ov 'priority priority)
     (overlay-put ov 'evaporate t)
-    (overlay-put ov 'TeX-fold-type type)
-    (overlay-put ov 'TeX-fold-display-string-spec display-string-spec)
-    ov))
-
-(defun TeX-fold--make-misc-overlay (start end display-string display-string-spec)
-  "Create a miscellaneous overlay between START and END.
-DISPLAY-STRING is the display string, while DISPLAY-STRING-SPEC is as in
-`TeX-fold-make-overlay'.
-
-This function is intended to be used with verbatim environments and
-other miscellaneous folding constructs.  By contrast, the function
-`TeX-fold-make-overlay' is used in the implementation of
-`TeX-fold-hide-item', which applies to typical macros, environments and
-math."
-  (let ((priority (TeX-overlay-prioritize start end))
-        (ov (make-overlay start end)))
-    (overlay-put ov 'category 'TeX-fold)
-    (overlay-put ov 'priority priority)
-    (overlay-put ov 'evaporate t)
-    (overlay-put ov 'display display-string)
+    (when type
+      (overlay-put ov 'TeX-fold-type type))
     (overlay-put ov 'TeX-fold-display-string-spec display-string-spec)
+    (when display-string
+      (overlay-put ov 'display display-string))
     ov))
 
 (defun TeX-fold-item-end (start type)
@@ -894,24 +1124,24 @@ Replace them with the respective macro argument."
         ((expand (spec &optional index)
            ;; If there is something to replace and the closing delimiter
            ;; matches the opening one…
-           (if-let (((string-match "\\([[{<(]\\)\\([1-9]\\)\\([]}>)]\\)"
-                                   spec index))
-                    (open (string-to-char (match-string 1 spec)))
-                    (num (string-to-number (match-string 2 spec)))
-                    (close (string-to-char (match-string 3 spec)))
-                    ((equal close (cdr (assoc open delims)))))
+           (if-let* (((string-match "\\([[{<(]\\)\\([1-9]\\)\\([]}>)]\\)"
+                                    spec index))
+                     (open (string-to-char (match-string 1 spec)))
+                     (num (string-to-number (match-string 2 spec)))
+                     (close (string-to-char (match-string 3 spec)))
+                     ((equal close (cdr (assoc open delims)))))
                ;; … then replace it and move on.  Otherwise, it must have been
                ;; a spurious spec, so abort.
-               (when-let ((arg (car (save-match-data
-                                      (TeX-fold-macro-nth-arg
-                                       num ov-start ov-end (assoc open delims)))))
-                          (spec* (replace-match arg nil t spec)))
+               (when-let* ((arg (car (save-match-data
+                                       (TeX-fold-macro-nth-arg
+                                        num ov-start ov-end (assoc open delims)))))
+                           (spec* (replace-match arg nil t spec)))
                  (expand spec*
                          (+ (match-end 0) (- (length spec*) (length spec)))))
              ;; Nothing to replace: return the (completed) spec.
              spec)))
       (or (cl-loop for elt in spec-list
-                   do (when-let (expanded (expand elt))
+                   do (when-let* ((expanded (expand elt)))
                         (cl-return expanded)))
           TeX-fold-ellipsis))))
 
@@ -1113,6 +1343,104 @@ With zero or negative ARG turn mode off."
 ;;;###autoload
 (defalias 'tex-fold-mode #'TeX-fold-mode)
 
+;;; Miscellaneous folding
+
+;; This section provides functions for use in
+;; `TeX-fold-region-functions'.
+
+;;;; Verbatim constructs
+
+(defun TeX-fold--verb-data (&rest _args)
+  "Return data describing verbatim macro at point.
+Returns list of the form (START END CONTENT).  This should be called
+only in LaTeX modes."
+  (when-let* ((boundaries (LaTeX-verbatim-macro-boundaries))
+              (bound-start (car boundaries))
+              (bound-end (cdr boundaries))
+              (end-delim-char (char-before bound-end))
+              (start-delim-char (if (= end-delim-char ?\})
+                                    ?\{
+                                  end-delim-char))
+              (start-delim (char-to-string start-delim-char))
+              (verb-arg-start
+               (1+ (progn
+                     (goto-char bound-end)
+                     (if (string= start-delim TeX-grop)
+                         (progn (backward-sexp) (point))
+                       (forward-char -1)
+                       (search-backward start-delim bound-start t)))))
+              (verb-arg-end (1- bound-end)))
+    (list bound-start
+          bound-end
+          (buffer-substring verb-arg-start verb-arg-end))))
+
+(defun TeX-fold-verbs (start end)
+  "In LaTeX modes, fold verbatim macros between START and END.
+Replaces the verbatim content with its own text."
+  (when (derived-mode-p 'LaTeX-mode)
+    (save-excursion
+      (goto-char start)
+      (let ((re (concat (regexp-quote TeX-esc)
+                        (regexp-opt
+                         (append
+                          (LaTeX-verbatim-macros-with-braces)
+                          (LaTeX-verbatim-macros-with-delims))))))
+        (while (let ((case-fold-search nil))
+                 (re-search-forward re end t))
+          (when-let* ((data (TeX-fold--verb-data))
+                      (verb-start (nth 0 data))
+                      (verb-end (nth 1 data))
+                      (verb-content (nth 2 data)))
+            (TeX-fold-make-overlay
+             verb-start verb-end
+             'misc
+             (lambda (&rest _args)
+               (nth 2 (TeX-fold--verb-data)))
+             verb-content)))))))
+
+;;;; Quotes
+
+(defcustom TeX-fold-open-quote "“"
+  "Folded version of opening quote."
+  :type 'string
+  :package-version '(auctex . "14.0.8"))
+
+(defcustom TeX-fold-close-quote "”"
+  "Folded verison of closing quote."
+  :type 'string
+  :package-version '(auctex . "14.0.8"))
+
+(defcustom TeX-fold-quotes-on-insert nil
+  "Non-nil means to automatically fold LaTeX quotes when they are inserted.
+Consulted by `TeX-insert-quote'."
+  :type 'boolean
+  :package-version '(auctex . "14.0.8"))
+
+(defun TeX-fold-quotes (start end)
+  "Fold LaTeX quotes between START and END.
+Replaces opening and closing quotes with `TeX-fold-open-quote' and
+`TeX-fold-close-quote', respectively, except in math environments,
+verbatim contexts and comments."
+  (pcase-let ((`(,open-quote ,close-quote _) (TeX-get-quote-characters)))
+    (save-excursion
+      (goto-char start)
+      (let ((regexp (regexp-opt (list open-quote close-quote))))
+        (while (re-search-forward regexp end t)
+          (let ((str (if (string= (match-string-no-properties 0) open-quote)
+                         TeX-fold-open-quote
+                       TeX-fold-close-quote))
+                (quote-start (match-beginning 0))
+                (quote-end (match-end 0)))
+            (unless (or (and (fboundp 'font-latex-faces-present-p)
+                             (font-latex-faces-present-p
+                              '(tex-math
+                                font-latex-verbatim-face
+                                font-latex-math-face
+                                font-lock-comment-face)
+                              quote-start))
+                        (texmathp))
+              (TeX-fold-make-overlay quote-start quote-end 'misc str str))))))))
+
 (provide 'tex-fold)
 
 ;;; tex-fold.el ends here
